@@ -12,6 +12,7 @@ import pymem.process
 import pymem.ressources.kernel32
 import pymem.ressources.structure
 import pymem.thread
+import pymem.pattern
 
 
 logger = logging.getLogger('pymem')
@@ -782,6 +783,36 @@ class Pymem(object):
             raise pymem.exception.MemoryReadError(address, byte, e.error_code)
         return value
 
+    def write_bytes(self, address, value, length):
+        """Write `value` to the given `address` into the current opened process.
+
+        Parameters
+        ----------
+        address: int
+            An address of the region of memory to be written.
+        value: bytes
+            the value to be written
+        length: int
+            Number of bytes to be written
+
+        Raises
+        ------
+        ProcessError
+            If there id no opened process
+        MemoryWriteError
+            If WriteProcessMemory failed
+        TypeError
+            If address is not a valid integer
+        """
+        if not self.process_handle:
+            raise pymem.exception.ProcessError('You must open a process before calling this method')
+        if value is None or not isinstance(value, bytes):
+            raise TypeError('Invalid argument: {}'.format(value))
+        try:
+            pymem.memory.write_bytes(self.process_handle, address, value, length)
+        except pymem.exception.WinAPIError as e:
+            raise pymem.exception.MemoryWriteError(address, value, e.error_code)
+
     def write_int(self, address, value):
         """Write `value` to the given `address` into the current opened process.
 
