@@ -1,8 +1,5 @@
 """XXX"""
 import ctypes
-import ctypes.wintypes
-
-import pymem.ressources.structure
 
 dll = ctypes.WinDLL('psapi.dll')
 #: Retrieves a handle for each module in the specified process that meets the specified filter criteria.
@@ -29,4 +26,4 @@ GetModuleInformation.restype = ctypes.c_bool
 #:
 #: https://msdn.microsoft.com/en-us/library/windows/desktop/ms683198(v=vs.85).aspx
 GetModuleFileNameExA = dll.GetModuleFileNameExA
-GetModuleFileNameExA.restype = ctypes.c_ulong
\ No newline at end of file
+GetModuleFileNameExA.restype = ctypes.c_ulong
